﻿using C1.WPF.C1Chart;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace AddDragLineToChart
{
    /// <summary>
    /// MainWindow.xaml 的交互逻辑
    /// </summary>
    public partial class MainWindow : Window
    {

        bool isDown = false;

        public MainWindow()
        {
            InitializeComponent();
       

            SampleData.CreateData(chart);
            chart.ChartType = ChartType.LineSymbols;
            chart.Palette = ColorGeneration.Urban;

            var pnl = new ChartPanel();
            pnl.MouseLeftButtonDown += pnl_MouseLeftButtonDown;
            pnl.MouseMove += new MouseEventHandler(pnl_MouseMove);
            pnl.MouseLeftButtonUp += pnl_MouseLeftButtonUp;

            var vmarker = CreateMarker(false, new Point());
            pnl.Children.Add(vmarker);
            vmarker.Action = ChartPanelAction.None;

            chart.View.Layers.Add(pnl);
        }

        void pnl_MouseLeftButtonUp(object sender, MouseButtonEventArgs e)
        {
            isDown = false;
        }

        void pnl_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            ChartPanel cnp = sender as ChartPanel;
            Point mouse = chart.View.PointToData(e.GetPosition(chart));
            var oldmarkerX = (cnp.Children[0] as ChartPanelObject).DataPoint.X;
            oldmarkerX = (Double.IsNaN(oldmarkerX)) ? 0 : oldmarkerX;
            var value = Math.Abs(mouse.X - oldmarkerX);
            if (Math.Abs(mouse.X - oldmarkerX) < 2.5)
            {
                isDown = true;
            }
            
        }
       
        void pnl_MouseMove(object sender, MouseEventArgs e)
        {
            if (isDown)
            {
                ChartPanel cnp = sender as ChartPanel;
                Point pnt = e.GetPosition(chart);
           
                var rect = chart.View.PlotRect;
                var oldmarkerX = chart.View.PointFromData((cnp.Children[0] as ChartPanelObject).DataPoint).X;
                oldmarkerX = (Double.IsNaN(oldmarkerX)) ? 0 : oldmarkerX;


                if (rect.Contains(pnt))
                {
                    cnp.Children.Clear();
                    var vmarker = CreateMarker(false, pnt);
                    cnp.Children.Add(vmarker);
                }
            }
        }


        ChartPanelObject CreateMarker(bool isHorizontal, Point pnt)
        {
            var obj = new ChartPanelObject();

            var bdr = new Border()
            {
                BorderBrush = Background = new SolidColorBrush(Colors.Red),
                Padding = new Thickness(2),
            };

            if (isHorizontal)
            {
                bdr.BorderThickness = new Thickness(0, 2, 0, 0);
                bdr.Margin = new Thickness(0, -1, 0, 0);
                obj.HorizontalContentAlignment = HorizontalAlignment.Stretch;

                if (pnt.X == 0 && pnt.Y == 0)
                    obj.DataPoint = new Point(double.NaN, 0.5);

            }
            else
            {
                bdr.BorderThickness = new Thickness(2, 0, 0, 0);
                bdr.Margin = new Thickness(-1, 0, 0, 0);
                obj.VerticalContentAlignment = VerticalAlignment.Stretch;

                Point dpt = chart.View.PointToData(pnt);
                obj.DataPoint = new Point(dpt.X, double.NaN);
               
            }

            bdr.IsHitTestVisible = false;
            obj.Content = bdr;

            return obj;
        }

    }
}
